# Tutorial - **More** NER Statistics

Now that we have a Corpus loaded, let's investigate the rest of the `recon.stats` module.
The best way to use the `recon.stats` module is through Prodigy directly.


!!!tip
    I'm working on a dashboard for Recon to display all the statistics and distributions of NER data. These docs will be updated in depth with how to use all the stats through the dashboard. For a full reference see the [recon.stats API docs](/api/stats)